HoprPacket

Enum HoprPacket 

pub enum HoprPacket {
    Final(Box<HoprIncomingPacket>),
    Forwarded(Box<HoprForwardedPacket>),
    Outgoing(Box<HoprOutgoingPacket>),
}
Contains HOPR packet and its variants.

See HoprIncomingPacket, HoprForwardedPacket and HoprOutgoingPacket for details.

The members are intentionally boxed to equalize the variant sizes.

Variants



Final(Box<HoprIncomingPacket>)

The packet is intended for us



Forwarded(Box<HoprForwardedPacket>)

The packet must be forwarded



Outgoing(Box<HoprOutgoingPacket>)

The packet that is being sent out by us

Implementations

Source

impl HoprPacket

Source

impl HoprPacket

pub const fn is_final(&self) -> bool

Returns true if the enum is HoprPacket::Final otherwise false

pub const fn is_forwarded(&self) -> bool

Returns true if the enum is HoprPacket::Forwarded otherwise false

pub const fn is_outgoing(&self) -> bool

Returns true if the enum is HoprPacket::Outgoing otherwise false

Source

impl HoprPacket

pub fn packet_tag(&self) -> Option<&PacketTag>

Returns the [PacketTag] of forwarded or final packets, or None for outgoing packets.

Source

impl HoprPacket

pub const MAX_SURBS_IN_PACKET: usize

The maximum number of SURBs that fit into a packet that contains no message.

pub const PAYLOAD_SIZE: usize

Maximum message size when no SURBs are present in the packet.

See HoprPacket::max_surbs_with_message.

pub const SIZE: usize

The size of the packet including header, padded payload, ticket, and ack challenge.

pub fn into_outgoing<M: ProtocolKeyIdMapper<HoprSphinxSuite, HoprSphinxHeaderSpec>, P: NonEmptyPath<OffchainPublicKey> + Send, S: Into<PacketSignals>>( msg: &[u8], pseudonym: &HoprPseudonym, routing: PacketRouting<P>, chain_keypair: &ChainKeypair, ticket: TicketBuilder, mapper: &M, domain_separator: &Hash, signals: S, ) -> Result<(Self, Vec<HoprReplyOpener>)>

Constructs a new outgoing packet with the given path.

Arguments
  • msg packet payload.
  • pseudonym our pseudonym as packet sender.
  • routing routing to the destination.
  • chain_keypair private key of the local node.
  • ticket ticket builder for the first hop on the path.
  • mapper of the public key identifiers.
  • domain_separator channels contract domain separator.
  • signals optional signals passed to the packet’s final destination.

NOTE For the given pseudonym, the ReplyOpener order matters.

pub const fn max_surbs_with_message(msg_len: usize) -> usize

Calculates how many SURBs can be fitted into a packet that also carries a message of the given length.

pub const fn max_message_with_surbs(num_surbs: usize) -> usize

Calculates the maximum length of the message that can be carried by a packet with the given number of SURBs.

pub fn from_incoming<M, F>( data: &[u8], node_keypair: &OffchainKeypair, previous_hop: OffchainPublicKey, mapper: &M, reply_openers: F, ) -> Result<Self>

Deserializes the packet and performs the forward-transformation, so the packet can be further delivered (relayed to the next hop or read).