pub enum PacketRouting<P: NonEmptyPath<OffchainPublicKey> = TransportPath> {
ForwardPath {
forward_path: P,
return_paths: Vec<P>,
},
Surb(HoprSurbId, HoprSurb),
NoAck(OffchainPublicKey),
}Expand description
Determines options on how HOPR packet can be routed to its destination.
Variants
ForwardPath
The packet is routed directly via the given path. Optionally, return paths for attached SURBs can be specified.
Surb(HoprSurbId, HoprSurb)
The packet is routed via an existing SURB that corresponds to a pseudonym.
NoAck(OffchainPublicKey)
No acknowledgement packet: a special type of 0-hop packet that is not going to be acknowledged but can carry a payload.