pub struct HoprIncomingPacket {
pub packet_tag: PacketTag,
pub ack_key: Option<HalfKey>,
pub previous_hop: OffchainPublicKey,
pub plain_text: Box<[u8]>,
pub sender: HoprPseudonym,
pub surbs: Vec<(HoprSurbId, HoprSurb)>,
pub signals: PacketSignals,
}Expand description
Represents a packet incoming to its final destination.
Fields
packet_tag: PacketTagPacket’s authentication tag.
ack_key: Option<HalfKey>Acknowledgement to be sent to the previous hop.
In case an acknowledgement is not required, this field is None. This arises specifically
in case the message payload is used to send one or more acknowledgements in the payload.
previous_hop: OffchainPublicKeyAddress of the previous hop.
plain_text: Box<[u8]>Decrypted packet payload.
sender: HoprPseudonymPseudonym of the packet creator.
surbs: Vec<(HoprSurbId, HoprSurb)>List of SURBs to be used for replies sent to the packet creator.
signals: PacketSignalsAdditional packet signals from the lower protocol layer passed from the packet sender.
Zero if no signal flags were specified.