pub struct HoprOutgoingPacket {
pub packet: MetaPacket<HoprSphinxSuite, HoprSphinxHeaderSpec, PAYLOAD_SIZE_INT>,
pub ticket: Ticket,
pub next_hop: OffchainPublicKey,
pub ack_challenge: HalfKeyChallenge,
pub encrypted_pix_share: Option<TaggedEncryptedPartialSsaShare<HoprPixSpec>>,
}Expand description
Represents a packet destined for another node.
Fields
packet: MetaPacket<HoprSphinxSuite, HoprSphinxHeaderSpec, PAYLOAD_SIZE_INT>Encrypted packet.
ticket: TicketTicket for this node.
next_hop: OffchainPublicKeyNext hop this packet should be sent to.
ack_challenge: HalfKeyChallengeAcknowledgement challenge solved once the next hop sends us an acknowledgement.
PIX protocol encrypted partial SSA share to be decrypted once the next hop sends back an acknowledgement.
This is populated only if this is a return path packet and the associated SURB contained an encrypted partial SSA share.