struct PathKeyData {
pub shared_keys: SharedKeys<<HoprSphinxSuite as SphinxSuite>::E, <HoprSphinxSuite as SphinxSuite>::G>,
pub por_strings: Vec<ProofOfRelayString>,
pub por_values: ProofOfRelayValues,
}Expand description
Shared key data for a path.
This contains the derived shared secrets and Proof of Relay data for a path.
Fields
Shared secrets for the path.
por_strings: Vec<ProofOfRelayString>Proof of Relay data for each hop on the path.
por_values: ProofOfRelayValuesProof of Relay values for the first ticket on the path.
Implementations